@@ -56,7 +56,8 @@ class AlarmDisplayClock(clock.Clock):
         
         if (self.font_name is not None) and self.font_name.startswith("Klingon") :
             text = clock.to_klingon_digits(text)
-            abrv = clock.to_klingon_text(abrv)
+            if self.twelve_hour_mode :
+                abrv = clock.to_klingon_text(abrv)
 
         self.context.text_path(text)
 
@@ -99,7 +100,8 @@ class AlarmDisplayClock(clock.Clock):
         
             if (self.font_name is not None) and self.font_name.startswith("Klingon") :
                 text = clock.to_klingon_digits(text)
-                abrv = clock.to_klingon_text(abrv)
+                if self.twelve_hour_mode :
+                    abrv = clock.to_klingon_text(abrv)
 
             self.context.text_path(text)
 
